package org.jpy;

interface PyObjectCleanup {
    int threadSafeCleanup();
}
